@@ -1,17 +1,16 @@
 # -*- coding: utf-8 -*-
-#!/usr/bin/env python
 # vim: set fileencoding=utf8:
 """
 backends for django-author
 
 AUTHOR:
     lambdalisue[Ali su ae] (lambdalisue@hashnote.net)
-    
+
 Copyright:
     Copyright 2011 Alisue allright reserved.
 
 License:
-    Licensed under the Apache License, Version 2.0 (the "License"); 
+    Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at
 
@@ -25,12 +24,15 @@ License:
 """
 __AUTHOR__ = "lambdalisue (lambdalisue@hashnote.net)"
 from django.conf import settings
+from django.contrib import auth
 from django.core.exceptions import ImproperlyConfigured
-from middlewares import get_request
+
+from .middlewares import get_request
+
 
 class AuthorDefaultBackend(object):
     """Author default backend
-    
+
     Get current user from request stored in thread_locals.
     Return None when request.user is not detected include request.user
     is AnonymousUser
@@ -38,15 +40,22 @@ class AuthorDefaultBackend(object):
     """
 
     def __init__(self):
+
         required_middleware = 'author.middlewares.AuthorDefaultBackendMiddleware'
-        if required_middleware not in settings.MIDDLEWARE_CLASSES:
+
+        middlewares = settings.MIDDLEWARE
+
+        if (
+                required_middleware not in middlewares
+        ):
             raise ImproperlyConfigured(
-                    'Error "%s" is not found in MIDDLEWARE_CLASSES. '
-                    'It is required to use AuthorDefaultBackend' % required_middleware)
+                'Error "%s" is not found in MIDDLEWARE_CLASSES nor MIDDLEWARE. '
+                'It is required to use AuthorDefaultBackend' % required_middleware,
+            )
+
     def _get_user_model(self):
         """get user model class"""
-        from django.contrib.auth.models import User
-        return User
+        return auth.get_user_model()
 
     def _get_request(self):
         """get current request"""
@@ -61,9 +70,10 @@ class AuthorDefaultBackend(object):
         # AnonymousUser
         return None
 
+
 class AuthorSystemUserBackend(AuthorDefaultBackend):
     """Author System user backend
-    
+
     Get current user from request stored in thread_locals.
     Return System user when request.user is not detected include request.user
     is AnonymousUser
