@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-#!/usr/bin/env python
 # vim: set fileencoding=utf8:
 """
 middlewares for django-author
@@ -7,12 +6,12 @@ middlewares for django-author
 
 AUTHOR:
     lambdalisue[Ali su ae] (lambdalisue@hashnote.net)
-    
+
 Copyright:
     Copyright 2011 Alisue allright reserved.
 
 License:
-    Licensed under the Apache License, Version 2.0 (the "License"); 
+    Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at
 
@@ -25,18 +24,23 @@ License:
     limitations under the License.
 """
 __AUTHOR__ = "lambdalisue (lambdalisue@hashnote.net)"
-try:
-    from threading import local
-except ImportError:
-    from django.utils._threading_local import local
+from threading import local
+
+from django.utils.deprecation import MiddlewareMixin
 
 __all__ = ['get_request', 'AuthorDefaultBackendMiddleware']
 _thread_locals = local()
 
+
 def get_request():
     """Get request stored in current thread"""
     return getattr(_thread_locals, 'request', None)
 
-class AuthorDefaultBackendMiddleware(object):
+
+class AuthorDefaultBackendMiddleware(MiddlewareMixin):
     def process_request(self, request):
         _thread_locals.request = request
+
+    def process_response(self, request, response):
+        _thread_locals.request = None
+        return response
