@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-#!/usr/bin/env python
 # vim: set fileencoding=utf8:
 """
 signal recivers for django-author
@@ -7,12 +6,12 @@ signal recivers for django-author
 
 AUTHOR:
     lambdalisue[Ali su ae] (lambdalisue@hashnote.net)
-    
+
 Copyright:
     Copyright 2011 Alisue allright reserved.
 
 License:
-    Licensed under the Apache License, Version 2.0 (the "License"); 
+    Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at
 
@@ -29,14 +28,18 @@ import logging
 
 from django.conf import settings
 from django.db.models.signals import pre_save
-from django.contrib.contenttypes.models import ContentType
 
 logger = logging.getLogger(__name__)
 
+
 def pre_save_callback(sender, instance, **kwargs):
     from . import get_backend
 
-    if "%s.%s" % (instance._meta.app_label, str(instance.__class__).lower()) in settings.AUTHOR_IGNORE_MODELS:
+    if (
+        hasattr(instance._meta, 'app_label')
+        and "%s.%s" % (instance._meta.app_label, instance._meta.model_name)
+        in settings.AUTHOR_IGNORE_MODELS
+    ):
         return
     if not hasattr(instance, settings.AUTHOR_CREATED_BY_FIELD_NAME):
         return
@@ -49,10 +52,12 @@ def pre_save_callback(sender, instance, **kwargs):
     if hasattr(instance, settings.AUTHOR_UPDATED_BY_FIELD_NAME):
         setattr(instance, settings.AUTHOR_UPDATED_BY_FIELD_NAME, user)
 
+
 def register():
     if settings.AUTHOR_MODELS:
         for model in settings.AUTHOR_MODELS:
             app_label, model = model.split('.', 1)
+            from django.contrib.contenttypes.models import ContentType
             ct = ContentType.objects.get_by_natural_key(app_label, model)
             pre_save.connect(pre_save_callback, sender=ct.model_class())
     else:
